@@ -1,7 +1,7 @@
 ##**********************************************************************
 ##**********************************************************************
 ##
-##  RANDOM SURVIVAL FOREST 1.0.0
+##  RANDOM SURVIVAL FOREST 2.0.0
 ##
 ##  Copyright 2006, Cleveland Clinic
 ##
@@ -54,7 +54,7 @@
 ##**********************************************************************
 ##**********************************************************************
 
-rsf.news <- function() {
+rsf.news <- function(...) {
     newsfile <- file.path(system.file(package="randomSurvivalForest"), "NEWS")
     file.show(newsfile)
 }
